You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@ozone.apache.org by "Attila Doroszlai (Jira)" <ji...@apache.org> on 2026/06/10 08:14:00 UTC
[jira] [Created] (HDDS-15523) Speed up TestOMDbCheckpointServletInodeBasedXfer
Attila Doroszlai created HDDS-15523:
---------------------------------------
Summary: Speed up TestOMDbCheckpointServletInodeBasedXfer
Key: HDDS-15523
URL: https://issues.apache.org/jira/browse/HDDS-15523
Project: Apache Ozone
Issue Type: Sub-task
Components: test
Reporter: Attila Doroszlai
{code}
Tests run: 13, Failures: 0, Errors: 0, Skipped: 0, Time elapsed: 179.2 s -- in org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testContentsOfTarballWithSnapshot(boolean)[1] -- Time elapsed: 21.88 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testContentsOfTarballWithSnapshot(boolean)[2] -- Time elapsed: 23.90 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testBootstrapOnFollowerConsistency -- Time elapsed: 24.06 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testWriteDBToArchive(boolean)[1] -- Time elapsed: 0.158 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testWriteDBToArchive(boolean)[2] -- Time elapsed: 0.021 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testWriteDBToArchiveClosesFilesListStream -- Time elapsed: 0.126 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testBootstrapLockBlocksMultipleServices -- Time elapsed: 15.09 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testTarballBatching(boolean)[1] -- Time elapsed: 24.86 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testTarballBatching(boolean)[2] -- Time elapsed: 22.15 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testBootstrapLockCoordination -- Time elapsed: 0.403 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testCollectFilesFromDirSkipsDeletedFile -- Time elapsed: 0.026 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testSnapshotDBConsistency -- Time elapsed: 23.70 s
org.apache.hadoop.ozone.om.TestOMDbCheckpointServletInodeBasedXfer.testCheckpointIncludesSnapshotsFromFrozenState -- Time elapsed: 22.68 s
{code}
Most time is spent in starting/stopping cluster. Ideally it should be started only once (BeforeAll). Some test cases need to be tweaked to account for existing state.
CC [~sshenoy]
--
This message was sent by Atlassian Jira
(v8.20.10#820010)
---------------------------------------------------------------------
To unsubscribe, e-mail: issues-unsubscribe@ozone.apache.org
For additional commands, e-mail: issues-help@ozone.apache.org